@@ -46,7 +46,7 @@ impl PackedString {
     }
 
     #[inline]
-    pub const fn as_str(&self) -> &str {
+    pub fn as_str(&self) -> &str {
         // SAFETY: You can only construct a PackedString via a &str
         unsafe { ::std::str::from_utf8_unchecked(&self.buffer) }
     }
