@@ -12,6 +12,11 @@ fn rand_unicode() -> impl Strategy<Value = String> {
     proptest::collection::vec(proptest::char::any(), 0..80).prop_map(|v| v.into_iter().collect())
 }
 
+// generates groups upto 40 strings long of random unicode strings, upto 80 chars long
+fn rand_unicode_collection() -> impl Strategy<Value = Vec<String>> {
+    proptest::collection::vec(rand_unicode(), 0..40)
+}
+
 proptest! {
     #[test]
     fn test_strings_roundtrip(word in rand_unicode()) {
@@ -32,6 +37,19 @@ proptest! {
             prop_assert!(compact.is_heap_allocated())
         }
     }
+
+    #[test]
+    fn test_char_iterator_roundtrips(word in rand_unicode()) {
+        let compact: CompactStr = word.clone().chars().collect();
+        prop_assert_eq!(&word, &compact)
+    }
+
+    #[test]
+    fn test_string_iterator_roundtrips(collection in rand_unicode_collection()) {
+        let compact: CompactStr = collection.clone().into_iter().collect();
+        let word: String = collection.into_iter().collect();
+        prop_assert_eq!(&word, &compact);
+    }
 }
 
 #[test]
@@ -56,7 +74,7 @@ fn test_const_creation() {
 #[test]
 fn test_short_ascii() {
     // always inlined on all archs
-    let strs = ["nyc", "statue", "liberty", "img_1234.png"];
+    let strs = vec!["nyc", "statue", "liberty", "img_1234.png"];
 
     for s in strs {
         let compact = CompactStr::new(s);
@@ -68,7 +86,7 @@ fn test_short_ascii() {
 
 #[test]
 fn test_short_unicode() {
-    let strs = [
+    let strs = vec![
         ("🦀", false),
         ("🌧☀️", false),
         #[cfg(target_pointer_width = "64")]
@@ -88,7 +106,7 @@ fn test_short_unicode() {
 
 #[test]
 fn test_medium_ascii() {
-    let strs = [
+    let strs = vec![
         "rustconf 2021",
         "new york city",
         "nyc pizza is good",
@@ -110,7 +128,7 @@ fn test_medium_ascii() {
 
 #[test]
 fn test_medium_unicode() {
-    let strs = [
+    let strs = vec![
         ("☕️👀😁🎉", false),
         // str is 24 bytes long, and leading character is non-ASCII, so it gets heap allocated
         ("🦀😀😃😄😁🦀", true),
@@ -140,3 +158,13 @@ fn test_from_str_trait() {
 
     assert_eq!(s, c);
 }
+
+#[test]
+fn test_from_char_iter() {
+    let s = "\u{0} 0 \u{0}a𐀀𐀀 𐀀a𐀀";
+    println!("{}", s.len());
+    let compact: CompactStr = s.chars().into_iter().collect();
+
+    assert!(compact.is_heap_allocated());
+    assert_eq!(s, compact);
+}
